@@ -223,7 +223,7 @@ class JSON2EDCLineageFiles:
             tgt_entity_uuid = self.get_entity(entity_uuid=entity)
             if tgt_entity_uuid is None:
                 result = messages.message["target_entity_not_found"]
-                result["info"] = "Could not find entity with uuid >%s< " % (entity)
+                result["info"] = "Could not find entity with uuid >%s< in to_entities >%s<" % (entity, str(to_entities))
                 overall_result = result
                 continue
             else:
